@@ -28,7 +28,7 @@ import requests
 from aiohttp import ClientResponseError
 from asgiref.sync import sync_to_async
 
-from airflow.exceptions import AirflowException
+from airflow.providers.common.compat.sdk import AirflowException
 from airflow.providers.http.hooks.http import HttpAsyncHook, HttpHook
 
 if TYPE_CHECKING:
@@ -559,7 +559,7 @@ class LivyAsyncHook(HttpAsyncHook):
                     url,
                     json=data if self.method in ("POST", "PATCH") else None,
                     params=data if self.method == "GET" else None,
-                    headers=headers,
+                    headers=_headers or None,
                     auth=auth,
                     **extra_options,
                 )
@@ -629,7 +629,10 @@ class LivyAsyncHook(HttpAsyncHook):
         """
         self._validate_session_id(session_id)
         self.log.info("Fetching info for batch session %s", session_id)
-        result = await self.run_method(endpoint=f"{self.endpoint_prefix}/batches/{session_id}/state")
+        result = await self.run_method(
+            endpoint=f"{self.endpoint_prefix}/batches/{session_id}/state",
+            headers=self.extra_headers,
+        )
         if result["status"] == "error":
             self.log.info(result)
             return {"batch_state": "error", "response": result, "status": "error"}
@@ -665,7 +668,9 @@ class LivyAsyncHook(HttpAsyncHook):
         self._validate_session_id(session_id)
         log_params = {"from": log_start_position, "size": log_batch_size}
         result = await self.run_method(
-            endpoint=f"{self.endpoint_prefix}/batches/{session_id}/log", data=log_params
+            endpoint=f"{self.endpoint_prefix}/batches/{session_id}/log",
+            data=log_params,
+            headers=self.extra_headers,
         )
         if result["status"] == "error":
             self.log.info(result)
